amzn_cooccur_net: Co-Occurrence Networks

View source: R/amzn_cooccur_net.R

amzn_cooccur_netR Documentation

Co-Occurrence Networks

Description

Count and plot the number of times pairs of words co-occur within reviews.

The function requires the user to specify which star-rating to isolate and to choose how frequently terms must co-occur.

Usage

amzn_cooccur_net(data, star, nn)

Arguments

data

Data frame created by GSPtext::get_reviews() or in the same format

star

Star rating of reviews that should be plotted

nn

Minimum number of co-occurrences that should be used in the plot

Value

ggraph plot

Examples

## Not run: 
amzn_cooccur_net(data, star = 5, nn = 15)
## End(Not run)

taylorgrant/GSPtext documentation built on April 15, 2023, 10:56 p.m.