View source: R/amzn_cooccur_net.R
| amzn_cooccur_net | R Documentation |
Count and plot the number of times pairs of words co-occur within reviews.
The function requires the user to specify which star-rating to isolate and to choose how frequently terms must co-occur.
amzn_cooccur_net(data, star, nn)
data |
Data frame created by |
star |
Star rating of reviews that should be plotted |
nn |
Minimum number of co-occurrences that should be used in the plot |
ggraph plot
## Not run:
amzn_cooccur_net(data, star = 5, nn = 15)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.